# Airplane Python SDK [![PyPI](https://img.shields.io/pypi/v/airplanesdk)](https://pypi.org/project/airplanesdk/) [![PyPI - License](https://img.shields.io/pypi/l/airplanesdk)](./LICENSE) [![Docs](https://img.shields.io/badge/Docs-airplane-blue)](https://docs.airplane.dev/creating-tasks/python)

SDK for writing [Airplane](https://airplane.dev) tasks in Python.

To learn more, see [the Airplane SDK docs](https://docs.airplane.dev/tasks/python-sdk).
